#!/bin/bash
#
# Extract moduli from RSA certificates in PEM format
#
# Version: 1.0 (vm, vs, be, mf)
# Version: 2.0 (bb) / 2020.08.13

echo -e 'Certificate moduli extractor.\n';

# Read dir and check if exists
pem_dir="$1"
if [ -d "$pem_dir" ]; then
    echo "Search pem files in directory $pem_dir"
elif [ -n "$pem_dir" -a ! -d "$pem_dir" ]; then
    echo "Directory $pem_dir does not exist!"
fi

[ ! -d "$pem_dir" ] && echo -ne "Enter the path to the pem files directory: "
while [ ! -d "$pem_dir" ]; do
    read pem_dir
    if [ ! -d "$pem_dir" ]; then
        echo -ne "Directory $pem_dir does not exist! Try again: "
    fi
done

# Find certificates in dir
certs=$( find "$pem_dir" -type f -name "*.pem" | sort )

# Extract the modulus from each certificate
echo -n "" > moduli
_oldIFS=$IFS
IFS=$'\n'
for cert in $certs; do
    echo " :: Extract $cert..."
    openssl x509 -noout -modulus -in "$cert" | sed 's/Modulus=//g' >> moduli
done
IFS=$_oldIFS

# Save the filenames for future reference
echo "$certs" > filenames

# Print the path of the files created
echo -e "\nFinished."
echo "Moduli file: ${PWD}/moduli"
echo -e "Filenames file: ${PWD}/filenames\n"
